# fitdist - Probability density fitting.

[![Python](https://img.shields.io/pypi/pyversions/fitdist)](https://img.shields.io/pypi/pyversions/fitdist)
[![PyPI Version](https://img.shields.io/pypi/v/fitdist)](https://pypi.org/project/fitdist/)
[![License](https://img.shields.io/badge/license-MIT-green.svg)](https://github.com/erdogant/fitdist/blob/master/LICENSE)
[![Sphinx](https://img.shields.io/badge/Sphinx-Docs-blue)](https://erdogant.github.io/distfit/)
[![Downloads](https://pepy.tech/badge/fitdist/week)](https://pepy.tech/project/fitdist/week)

* ``fitdist`` is Python package that originates from ``distfit`` library.
* More information can be found [at the distfit library](https://github.com/erdogant/distfit)

### Maintainer
	Erdogan Taskesen, github: [erdogant](https://github.com/erdogant)
	Contributions are welcome.
	See [LICENSE](LICENSE) for details.
